==> RsCmwLteSig-3.7.62.25-py3-none-any.whl: RsCmwLteSig/Implementations/Sense_/Connection_/Scc_/UdChannels_/Laa_/Fburst_/Downlink.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Downlink:
	"""Downlink commands group definition. 3 total commands, 3 Sub-groups, 0 group commands
	Repeated Capability: Stream, default value after init: Stream.S1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("downlink", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_stream_get', 'repcap_stream_set', repcap.Stream.S1)

	def repcap_stream_set(self, enum_value: repcap.Stream) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Stream.Default
		Default value after init: Stream.S1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_stream_get(self) -> repcap.Stream:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def fullSubframes(self):
		"""fullSubframes commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fullSubframes'):
			from .Downlink_.FullSubframes import FullSubframes
			self._fullSubframes = FullSubframes(self._core, self._base)
		return self._fullSubframes

	@property
	def pipSubFrames(self):
		"""pipSubFrames commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pipSubFrames'):
			from .Downlink_.PipSubFrames import PipSubFrames
			self._pipSubFrames = PipSubFrames(self._core, self._base)
		return self._pipSubFrames

	@property
	def pepSubFrames(self):
		"""pepSubFrames commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pepSubFrames'):
			from .Downlink_.PepSubFrames import PepSubFrames
			self._pepSubFrames = PepSubFrames(self._core, self._base)
		return self._pepSubFrames

	def clone(self) -> 'Downlink':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Downlink(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group

==> RsCmwLteSig-3.7.62.26-py3-none-any.whl: RsCmwLteSig/Implementations/Sense_/Connection_/Scc_/UdChannels_/Laa_/Fburst_/Downlink.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Downlink:
	"""Downlink commands group definition. 3 total commands, 3 Sub-groups, 0 group commands
	Repeated Capability: Stream, default value after init: Stream.S1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("downlink", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_stream_get', 'repcap_stream_set', repcap.Stream.S1)

	def repcap_stream_set(self, enum_value: repcap.Stream) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Stream.Default
		Default value after init: Stream.S1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_stream_get(self) -> repcap.Stream:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def fullSubFrames(self):
		"""fullSubFrames commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fullSubFrames'):
			from .Downlink_.FullSubFrames import FullSubFrames
			self._fullSubFrames = FullSubFrames(self._core, self._base)
		return self._fullSubFrames

	@property
	def pipSubFrames(self):
		"""pipSubFrames commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pipSubFrames'):
			from .Downlink_.PipSubFrames import PipSubFrames
			self._pipSubFrames = PipSubFrames(self._core, self._base)
		return self._pipSubFrames

	@property
	def pepSubFrames(self):
		"""pepSubFrames commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pepSubFrames'):
			from .Downlink_.PepSubFrames import PepSubFrames
			self._pepSubFrames = PepSubFrames(self._core, self._base)
		return self._pepSubFrames

	def clone(self) -> 'Downlink':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Downlink(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
